IterableChecks extension

on

Methods

hasTheSameElements<T>(Iterable<T> other) bool

Available on Iterable, provided by the IterableChecks extension

Return true if all items in this are also in other
isSubList<T>(Iterable<T> other) bool

Available on Iterable, provided by the IterableChecks extension

Return true if this is a sublist of other.