push method
void
push(
- E item
Pushes an element onto the top of the stack.
Implementation
void push(E item) => _list.add(item);
Pushes an element onto the top of the stack.
void push(E item) => _list.add(item);