IntlString class

Aligns a String with its locale

Implemented types

Constructors

IntlString(String value, {Locale? locale, Locale currentLocaleFunction()?})
Constructor
IntlString.constant(String value, {String? languageTag})
A strict const constructor for static code-generation.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
locale → Locale
The locale of the string
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The value of the string
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, String>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

tryParseLocale(String localeIdentifier) → Locale?
Return true if the localeIdentifier can be parsed, null otherwise.