IntlStrings class

A map of locales to IntlStrings

Implemented types

Constructors

IntlStrings(List<IntlString> values, {Locale? defaultLocale, Locale currentLocaleFunction()?, Locale? fallbackLocale})
Constructor

Properties

defaultLocale → Locale
The default locale to use when a locale isn't requested
final
fallbackLocale → Locale
The locale to use when no match is found - 'en' by default
final
hashCode int
The hash code for this object.
no setterinherited
locales Set<Locale?>
The list of all mapped locales
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
string String?
Convenience property to call call with no locale
no setter

Methods

call({Locale? locale}) String?
Convenience method to call getString
getString({Locale? locale}) IntlString?
Given a locale, return the corresponding IntlString if it exists.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Map<String, String>>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited