StringExtension extension

on

Properties

hasNoWhitespace bool

Available on String, provided by the StringExtension extension

True if there is no whitespace in the string, False otherwise.
no setter
hasWhitespace bool

Available on String, provided by the StringExtension extension

True if there is whitespace in the string, False otherwise.
no setter
isAsciiControlCharacter bool

Available on String, provided by the StringExtension extension

True if the string has 1 character and it's an ASCII control character.
no setter
isAsciiDigit bool

Available on String, provided by the StringExtension extension

no setter
isAsciiLetter bool

Available on String, provided by the StringExtension extension

no setter
isAsciiLetterLowercase bool

Available on String, provided by the StringExtension extension

no setter
isAsciiLetterUppercase bool

Available on String, provided by the StringExtension extension

no setter
isAsciiPunctuationCharacter bool

Available on String, provided by the StringExtension extension

no setter
isCarriageReturn bool

Available on String, provided by the StringExtension extension

True if the string has 1 character and it's a CR.
no setter
isCrLf bool

Available on String, provided by the StringExtension extension

no setter
isEol bool

Available on String, provided by the StringExtension extension

no setter
isEolChar bool

Available on String, provided by the StringExtension extension

True if the string has 1 character and it's a CR or LF.
no setter
isLineFeed bool

Available on String, provided by the StringExtension extension

True if the string has 1 character and it's a LF.
no setter
isNotWhitespace bool

Available on String, provided by the StringExtension extension

True if the string is not entirely made up of whitespace characters, False otherwise.
no setter
isUnicodePunctuationCharacter bool

Available on String, provided by the StringExtension extension

no setter
isWhitespace bool

Available on String, provided by the StringExtension extension

True if the string is entirely made up of whitespace characters, False otherwise.
no setter

Methods

all(bool test(String element)) bool

Available on String, provided by the StringExtension extension

True if all characters match the given test.
clipRight(int n) String

Available on String, provided by the StringExtension extension

Clip the n rightmost characters
cutFirst(String separator) → (String, String, bool)

Available on String, provided by the StringExtension extension

cut using first instance of separator, returning the before and after parts
toUpperCaseFirstLetter() String

Available on String, provided by the StringExtension extension