hasNoWhitespace property
bool
get
hasNoWhitespace
True if there is no whitespace in the string, False otherwise.
Implementation
bool get hasNoWhitespace => !hasWhitespace;
True if there is no whitespace in the string, False otherwise.
bool get hasNoWhitespace => !hasWhitespace;