isNotWhitespace property
bool
get
isNotWhitespace
True if the string is not entirely made up of whitespace characters, False otherwise.
Implementation
bool get isNotWhitespace => !isWhitespace;
True if the string is not entirely made up of whitespace characters, False otherwise.
bool get isNotWhitespace => !isWhitespace;