StringList class

Container for a string or a list of strings.

Constructors

StringList(String value)
StringList.fromList(List<String> values)
Creates a StringList from a list of strings.
StringList.fromString(String value)
Creates a StringList from a string.

Properties

firstOrNull String?
Returns the first string value.
no setter
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value List<String>
Returns the strings as a list
no setter

Methods

add(String s) StringList
Adds a string to the StringList, returning the updated StringList.
concatenate(String s) StringList
Concatenates a string to latest string in the StringList.
join({String separator = ''}) String
Returns the joined string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toList() List<String>
Return all string values in a list.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override