concatenate method
Concatenates a string to latest string in the StringList.
this is returned for chaining.
Implementation
StringList concatenate(String s) {
final newValue = _stack.pop() + s;
_stack.push(newValue);
return this;
}
Concatenates a string to latest string in the StringList.
this is returned for chaining.
StringList concatenate(String s) {
final newValue = _stack.pop() + s;
_stack.push(newValue);
return this;
}